==> 0.9.1.tar.gz: lib/src/repository_search.dart <==
import 'db_principal.dart';
import 'search_criteria.dart';
import 'search_result.dart';

/// Performs searches over the repository
abstract class RepositorySearch<TEntity> {
  /// Searches entities according to [criteria],
  /// returning a page of entities and the count
  /// of total entities that fit the given constraints.
  ///
  /// Implementations should filter the search results
  /// limiting them to entities belonging to
  /// the tenant of the [principal].
  ///
  /// By default, this method will search
  /// all entities in the collection owned by
  /// the [principal], except when the
  /// [permission] parameter is given.
  /// When the [permission] parameter has a
  /// non-null argument and the user identified
  /// by the [principal] has that permission,
  /// then all the entities in the collection
  /// belonging to the tenant within the criteria
  /// defined by the [criteria], regardless of
  /// their owner within the tenant.
  Future<SearchResult> searchWithCount(
    SearchCriteria criteria,
    DbPrincipal principal, {
    String? permission,
  });

  /// Searches entities according to [criteria] and returns the
  /// total count of entities fitting the constraints.
  ///
  /// Implementations should filter the search results
  /// limiting them to entities belonging to
  /// the tenant of the [principal].
  ///
  /// By default, this method will search
  /// all entities in the collection owned by
  /// the [principal], except when the
  /// [permission] parameter is given.
  /// When the [permission] parameter has a
  /// non-null argument and the user identified
  /// by the [principal] has that permission,
  /// then all the entities in the collection
  /// belonging to the tenant within the criteria
  /// defined by the [criteria], regardless of
  /// their owner within the tenant.
  Future<int> count(
    SearchCriteria criteria,
    DbPrincipal principal, {
    String? permission,
  });

  /// Searches entities according to [criteria],
  /// returning all the entities that fit the constraints.
  ///
  /// Implementations should filter the search results
  /// limiting them to entities belonging to
  /// the tenant of the [principal].
  ///
  /// By default, this method will search
  /// all entities in the collection owned by
  /// the [principal], except when the
  /// [permission] parameter is given.
  /// When the [permission] parameter has a
  /// non-null argument and the user identified
  /// by the [principal] has that permission,
  /// then all the entities in the collection
  /// belonging to the tenant within the criteria
  /// defined by the [criteria], regardless of
  /// their owner within the tenant.
  Stream<Map<String, dynamic>> search(
    SearchCriteria criteria,
    DbPrincipal principal, {
    String? permission,
  });
}

==> 1.0.0-rc.2.tar.gz: lib/src/repository_search.dart <==
import 'db_principal.dart';
import 'search_criteria.dart';
import 'search_result.dart';

/// Performs searches over the repository
abstract class RepositorySearch<TEntity> {
  /// Searches entities according to [criteria],
  /// returning a page of entities and the count
  /// of total entities that fit the given constraints.
  ///
  /// Implementations should filter the search results
  /// limiting them to entities belonging to
  /// the tenant of the [principal].
  ///
  /// By default, this method will search
  /// all entities in the collection owned by
  /// the [principal], except when the
  /// [permission] parameter is given.
  /// When the [permission] parameter has a
  /// non-empty argument and the user identified
  /// by the [principal] has that permission,
  /// then all the entities in the collection
  /// belonging to the tenant within the criteria
  /// defined by the [criteria], regardless of
  /// their owner within the tenant.
  Future<SearchResult> searchWithCount(
    SearchCriteria criteria,
    DbPrincipal principal, {
    String permission = '',
  });

  /// Searches entities according to [criteria] and returns the
  /// total count of entities fitting the constraints.
  ///
  /// Implementations should filter the search results
  /// limiting them to entities belonging to
  /// the tenant of the [principal].
  ///
  /// By default, this method will search
  /// all entities in the collection owned by
  /// the [principal], except when the
  /// [permission] parameter is given.
  /// When the [permission] parameter has a
  /// non-empty argument and the user identified
  /// by the [principal] has that permission,
  /// then all the entities in the collection
  /// belonging to the tenant within the criteria
  /// defined by the [criteria], regardless of
  /// their owner within the tenant.
  Future<int> count(
    SearchCriteria criteria,
    DbPrincipal principal, {
    String permission = '',
  });

  /// Searches entities according to [criteria],
  /// returning all the entities that fit the constraints.
  ///
  /// Implementations should filter the search results
  /// limiting them to entities belonging to
  /// the tenant of the [principal].
  ///
  /// By default, this method will search
  /// all entities in the collection owned by
  /// the [principal], except when the
  /// [permission] parameter is given.
  /// When the [permission] parameter has a
  /// non-empty argument and the user identified
  /// by the [principal] has that permission,
  /// then all the entities in the collection
  /// belonging to the tenant within the criteria
  /// defined by the [criteria], regardless of
  /// their owner within the tenant.
  Stream<Map<String, dynamic>> search(
    SearchCriteria criteria,
    DbPrincipal principal, {
    String permission = '',
  });
}
